Needing help?

- Enter your query in the text field. Make sure that attributes mentioned in the query are existent in the listed attributes underneath the input field
- (Optional) Select features. GBD will resolve the results against these features
- Each database has a set of features. You can download a database by clicking and show/hide its features with
- Now you can choose how we should handle your query: Either show you a sortable table in the browser (standard, also by pressing Enter), send you an URL file containing download URLs for all instances which match your query or send you a CSV file representing the results
- You can use the query multiple times - just remember we always use the currently selected features and currently typed query for each request